<?php

namespace Drupal\logrocket\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\user\Entity\User;
use Drupal\user\Entity\Role;

/**
 * Configure LogRocket App ID and user/role exclusions.
 */
class LogRocketSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['logrocket.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'logrocket_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('logrocket.settings');

    $form['app_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('LogRocket App ID'),
      '#default_value' => $config->get('app_id'),
      '#description' => $this->t("Enter your LogRocket App ID (e.g., 'your-org/your-project')"),
      '#required' => TRUE,
    ];

    // User selection.
    $logging_uids = $config->get('logging_user') ?? [];
    $logging_user = array_filter(array_map('Drupal\user\Entity\User::load', $logging_uids));

    $form['logging_user'] = [
      '#type' => 'entity_autocomplete',
      '#title' => $this->t('Users For LogRocket Session'),
      '#description' => $this->t('Select users for whom LogRocket should be enabled.'),
      '#target_type' => 'user',
      '#tags' => TRUE,
      '#multiple' => TRUE,
      '#default_value' => $logging_user,
    ];

    // Role selection for which LogRocket should be disabled.
    $role_options = [];
    foreach (Role::loadMultiple() as $role) {
      $role_options[$role->id()] = $role->label();
    }

    $form['disabled_roles'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Roles to Disable LogRocket Session'),
      '#description' => $this->t('Select roles for which LogRocket should be disabled. Leave empty to allow all roles.'),
      '#options' => $role_options,
      '#default_value' => $config->get('disabled_roles') ?? [],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $logging_users_input = $form_state->getValue('logging_user') ?? [];
    $uids = array_map(function ($user) {
      return is_array($user) ? $user['target_id'] : $user->id();
    }, $logging_users_input);

    $roles_input = array_filter($form_state->getValue('disabled_roles') ?? []);

    $this->config('logrocket.settings')
      ->set('app_id', $form_state->getValue('app_id'))
      ->set('logging_user', $uids)
      ->set('disabled_roles', $roles_input)
      ->save();

    parent::submitForm($form, $form_state);
  }

}
